#!/usr/bin/perl -T

use strict;
use warnings;

#*******************************************************************************
# Whois::Negistry module/class tests
#
# Author:   Jan Mach, jan.mach@cesnet.cz
# Version:  0.1
# Purpose:
#
#*******************************************************************************

use Data::Dumper;
#use Smart::Comments;

use Test::More tests => 18;
# First test if the module correctly compiles
BEGIN {
        use vars qw($TESTED_CLASS);
        $TESTED_CLASS = 'Whois::Negistry';

        use_ok('Tester');
        use_ok('Value::Convertor');
        use_ok('Value::IPv4ADDR');
        use_ok($TESTED_CLASS);
    }

# Debug output explicit ON switch
#Tester::DEBUG_ON();

# Debug output explicit OFF switch
#Tester::DEBUG_OFF();

# User should know, which version is beeing tested (just for sure)
diag("$TESTED_CLASS version: " . $Whois::Negistry::VERSION) if Tester::D();

# Now attempt to create a class instance and check it
my $instance = $TESTED_CLASS->new('./data/whois-negistry.json', 2, {'./data/iplist-cesnet' => 'special@cesnet.cz', './data/iplist-grid' => 'test@abuse.org'});
isa_ok($instance, $TESTED_CLASS);

# View the created instance
#diag("Instance dump 01: " . Dumper($instance)) if Tester::D();
diag("Instance dump 02: " . Dumper($instance->{EXCEPTIONS})) if Tester::D();

my @resultsA = $instance->find('146.102.1.1');
diag('Results A: '.Dumper(\@resultsA)) if Tester::D();
is(scalar @resultsA,                                  1,                        "Count check 01");
is($resultsA[0]->{'netname'},                         'VSE-TCZ',                "Value check 01");
is($resultsA[0]->{'first'}.":".$resultsA[0]->{'last'}, '2456158208:2456223743', "Value check 02");

my @resultsB = $instance->find('147.228.2.2');
diag('Results B: '.Dumper(\@resultsB)) if Tester::D();
is(scalar @resultsB,                                  1,                        "Count check 02");
is($resultsB[0]->{'netname'},                         'ZCU-TCZ',                "Value check 03");
is($resultsA[0]->{'first'}.":".$resultsA[0]->{'last'}, '2456158208:2456223743', "Value check 04");

my @resultsC = $instance->find('195.113.215.100');
diag('Results C: '.Dumper(\@resultsC)) if Tester::D();
is(scalar @resultsC,                                  2,                        "Count check 03");
is($resultsC[0]->{'netname'},                         'MENDELU-TCZ',            "Value check 05");
is($resultsA[0]->{'first'}.":".$resultsA[0]->{'last'}, '2456158208:2456223743', "Value check 06");

is($instance->find_abuses('146.102.1.1'),     'abuse@vse.cz',     "Abuse check 01");
is($instance->find_abuses('147.228.2.2'),     'abuse@zcu.cz',     "Abuse check 02");
is($instance->find_abuses('195.113.215.100'), 'abuse@mendelu.cz', "Abuse check 03");

#is($instance->find_abuses('195.113.180.157'), 'abuse@cvum.cz',    "Abuse check 04");
is($instance->find_abuses('195.113.180.157'), 'special@cesnet.cz', "Abuse check 04");
